@@ -22,7 +22,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
-#include <assert.h>
+#include <err.h>
 #include "prips.h"
 #include "except.h"
 
@@ -46,14 +46,18 @@ void set_exceptions(const char * const exp, int octet[4][256])
 		{
 			buffer[bufferind] = exp[i];
 			bufferind++;
-			assert(bufferind != 4); /* potential overflow... */
+			if (bufferind >= 3)
+				errx(1, "Invalid octet value specified for exclusion");
 		}
 		else
 		{
 			if(bufferind)
 			{
 				buffer[bufferind] = '\0';
-				octet[octind][excludeind] = atoi(buffer);
+				const int value = atoi(buffer);
+				if (value > 255)
+					errx(1, "Invalid octet value specified for exclusion");
+				octet[octind][excludeind] = value;
 				bufferind = 0;
 				excludeind++; 
 			}
@@ -61,6 +65,8 @@ void set_exceptions(const char * const exp, int octet[4][256])
 			if(exp[i] == '.')
 			{
 				octind++;
+				if (octind >= 4)
+					errx(1, "Too many dots specified in an exclusion pattern");
 				excludeind = 0;
 			}
 		}
