@@ -3,7 +3,7 @@
 
 /*
  * Copyright (C) 2001-2003  Daniel Kelly
- * Copyright (C) 2009, 2016  Peter Pentchev
+ * Copyright (C) 2009, 2016, 2018  Peter Pentchev
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,6 @@
  */
 
 void set_exceptions(const char *exp, int octet[4][256]);
-bool except(uint32_t *current, int octet[4][256]);
+bool except(uint32_t *current, int octet[4][256], int increment);
 
 #endif /* __except_h */
